use std::fs::File;

use clap::Parser;

mod api;
use api::APIClient;

mod crypto;
mod mp4;

#[derive(Parser, Debug)]
struct Args {
    auth_token: String,
    track_id: u32,
    format_id: u32
}

#[tokio::main]
async fn main() {
    let args = Args::parse();

    let mut client = APIClient::new();
    client.set_auth_token(&args.auth_token);

    let url_resp = client.get_track_url(args.track_id, args.format_id).await.unwrap();

    println!("{}", url_resp.url_template);
    println!("{}", hex::encode(url_resp.key));
    println!("{}", url_resp.n_segments);

    let track_id = args.track_id;
    let format_id = args.format_id;

    let path = format!("{track_id}-{format_id}");
    let mut file = File::create(path).unwrap();

    client.dl_track(&url_resp.url_template, &url_resp.key, url_resp.n_segments, &mut file).await.unwrap();
}